@@ -1,7 +1,7 @@
 // C++ source
 // This file is part of RGL.
 //
-// $Id: rglview.cpp 794 2010-10-07 16:58:13Z murdoch $
+// $Id: rglview.cpp 917 2013-01-23 23:54:52Z murdoch $
 
 
 
@@ -135,7 +135,6 @@ void RGLView::paint(void) {
 // user input
 //
 
-
 void RGLView::keyPress(int key)
 {
   switch(key) {
@@ -143,6 +142,9 @@ void RGLView::keyPress(int key)
       flags ^= FSHOWFPS;
       windowImpl->update();
       break;
+    case GUI_KeyESC:
+      selectState = msABORT;
+      break;
   }
 }
 
@@ -642,6 +644,8 @@ double* RGLView::getMousePosition()
 //
 void RGLView::mouseSelectionBegin(int mouseX,int mouseY)
 {
+	if (selectState == msABORT) return;
+	
 	mousePosition[0] = (float)mouseX/(float)width;
 	mousePosition[1] = (float)(height - mouseY)/(float)height;
 	mousePosition[2] = mousePosition[0];
@@ -658,6 +662,8 @@ void RGLView::mouseSelectionUpdate(int mouseX,int mouseY)
 
 void RGLView::mouseSelectionEnd()
 {
+	if (selectState == msABORT) return;
+	
 	selectState = msDONE;
 	View::update();
 }
